@@ -1,3 +1,4 @@
+from types import NoneType
 import requests
 import json
 
@@ -76,13 +77,52 @@ class Firebot:
             try:
                 response = requests.get(self.url+"api/v1/status")
                 if response.json() == {'connections': {'chat': True}}:
-                    status = "Firebot chat is connected"
+                    status = True
                 else:
-                    status = "Firebot chat is not connected"
+                    status = False
                 return status
             except:
                 attempts += 1
 
+    def get_allviewers(self):
+        """
+        Returns a list of all users in the firebot database.
+        """
+        attempts = 0
+        while attempts <= 5:
+            try:
+                response = requests.get(self.url+"api/v1/viewers")
+                rjson = response.json()
+                return rjson
+            except:
+                attempts += 1
+
+    def get_userdata(self, username):
+        """
+        Returns all data associated with a user.
+        """
+        attempts = 0
+        while attempts <= 5:
+            try:
+                response = requests.get(f'{self.url}api/v1/viewers/{username}?username=true')
+                rjson = response.json()
+                return rjson
+            except:
+                attempts += 1
+
+    def get_user_metadata(self, username, metadata):
+        """
+        Returns metadata associated with a user.
+        """
+        attempts = 0
+        while attempts <= 5:
+            try:
+                response = requests.get(f'{self.url}api/v1/viewers/{username}?username=true')
+                rjson = response.json()['metadata'][metadata]
+                return rjson
+            except:
+                attempts += 1
+
     def bot_chat(self, chatmessage):
         """
         Send a message as the bot.
@@ -893,3 +933,4 @@ class Firebot:
         }
         message = f"Successfully removed {amount} {currency} to all users in {role} role"
         self.sendit(data, message)
+
